<?php

namespace Projectify;

// Exit if accessed directly. 
if ( ! defined( 'ABSPATH' ) ) { exit; }


// Main Plugin Class
class Projectify_Plugin
{
	
	
    // Constructor
    public function __construct()
    {
        $this->add_actions();
		
    }
    public function pjfy_add_custom_meta_box()
	{
		add_meta_box('projectify-meta-box','Projectify Page Options', array($this,'pjfy_custom_meta_box_markup'), 'page', 'side', 'high', null);
	}
	public function pjfy_custom_meta_box_markup($object)
	{
		wp_nonce_field(basename(__FILE__), "pjfy-meta-box-nonce");

		?>
			<div class="pjfy_admin_post_options">
				<div class="pjfy_featured">
					<label for="pjfy-meta-box-featured">Featured Page</label>
					<?php
						$checkbox_value = get_post_meta($object->ID, "pjfy-meta-box-featured", true);

						if($checkbox_value == "")
						{
							?>
								<input name="pjfy-meta-box-featured" type="checkbox" value="true">
							<?php
						}
						else if($checkbox_value == "true")
						{
							?>  
								<input name="pjfy-meta-box-featured" type="checkbox" value="true" checked>
							<?php
						}
					?>

				</div>
			</div>
		<?php  
	}
	public function pjfy_save_custom_meta_box($post_id, $post, $update)
	{
		if (!isset($_POST["pjfy-meta-box-nonce"]) || !wp_verify_nonce($_POST["pjfy-meta-box-nonce"], basename(__FILE__)))
			return $post_id;

		if(!current_user_can("edit_post", $post_id))
			return $post_id;

		if(defined("DOING_AUTOSAVE") && DOING_AUTOSAVE)
			return $post_id;

		$slug = "page";
		if($slug != $post->post_type)
			return $post_id;

		$meta_box_dropdown_value = "";
		$meta_box_checkbox_value = "";

		if(isset($_POST["pjfy-meta-box-featured"]))
		{
			$meta_box_checkbox_value = $_POST["pjfy-meta-box-featured"];
		}   
		update_post_meta($post_id, "pjfy-meta-box-featured", $meta_box_checkbox_value);
	}
	public function projectify_fn_admin_scripts() {
		wp_enqueue_style('projectify-fn-admin-style',plugins_url( 'assets/css/admin-style.css', __FILE__ ), array(), PROJECTIFY_VERSION, 'all');
	}
    
	// Add Actions
    private function add_actions()
    {
		/****************************** Adding Post Option by Projectify ******************************/
		/********************************************************************************************/
		add_action('add_meta_boxes', array( $this, 'pjfy_add_custom_meta_box'));
		add_action('save_post', array( $this,'pjfy_save_custom_meta_box'), 10, 3);
		/********************************************************************************************/
		/********************************************************************************************/
        // Add New Elementor Categories
        add_action( 'elementor/init', array( $this, 'add_elementor_category' ), 999 );
        // Register Widget Scripts
        add_action( 'elementor/frontend/after_enqueue_scripts', array( $this, 'register_widget_scripts' ) );
        // Register Widget Styles
        add_action( 'elementor/frontend/after_enqueue_styles', array( $this, 'register_widget_styles' ) );
        // Register New Widgets
        add_action( 'elementor/widgets/widgets_registered', array( $this, 'register_widgets' ), 10 );
		
		add_action( 'admin_enqueue_scripts', array($this,'projectify_fn_admin_scripts') );
    }
    
	
    // Add New Categories to Elementor
    public function add_elementor_category()
    {
        \Elementor\Plugin::instance()->elements_manager->add_category( 'projectify-elements', array(
            'title' => __( 'Projectify Elements', 'projectify' ),
        ), 1 );
    }
    
    // Register Widget Scripts
    public function register_widget_scripts()
    {
		wp_enqueue_script( 'projectify_plugins', plugins_url( 'assets/js/plugins.js', __FILE__ ), array( 'jquery' ), true, PROJECTIFY_VERSION, 'all' );
		wp_enqueue_script( 'projectify_inito', plugins_url( 'assets/js/inito.js', __FILE__ ), array( 'jquery' ), true, PROJECTIFY_VERSION, 'all' );
		
    }
	
    // Register Widget Styles
    public function register_widget_styles()
    {
		wp_enqueue_style( 'projectify_style', plugins_url( 'assets/css/style.css', __FILE__ ), false, PROJECTIFY_VERSION, 'all' );
		wp_enqueue_style( 'projectify_plugins', plugins_url( 'assets/css/plugins.css', __FILE__ ), false, PROJECTIFY_VERSION, 'all' );
		wp_enqueue_style( 'projectify_fontello', plugins_url( 'assets/css/fontello.css', __FILE__ ), false, PROJECTIFY_VERSION, 'all' );
    }
    
	
    // Register New Widgets
    public function register_widgets()
    {
        $this->include_widgets();
		$this->include_widget_outputs();
    }
    
	
    // Include Widgets
    private function include_widgets()
    {
		foreach(glob(plugin_dir_path( __FILE__ ) . '/widgets/*.php' ) as $file ){
			$this->include_widget( $file );
		}
		
    }
	
	
	// Include and Load Widget
    private function include_widget($file)
    {
		
		$base  = basename( str_replace( '.php', '', $file ) );
		$class = ucwords( str_replace( '-', ' ', $base ) );
		$class = str_replace( ' ', '_', $class );
		$class = sprintf( 'Projectify\Widgets\%s', $class );
		
		require_once $file; // include widget php file
		
		if ( class_exists( $class ) ) {
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new $class ); // load widget class
		}
		
    }
	
	
	// call to widget outputs
	private function include_widget_outputs()
    {
		foreach(glob(plugin_dir_path( __FILE__ ) . '/widgets/output/*.php' ) as $file ){
			require_once $file;
		}
    }
	
	

}